@@ -88,16 +88,13 @@ from ..config.settings import (
     MAX_PAGINATION_PAGE_SIZE,
     TESTING,
     INACTIVE_USER_DAYS,
-    GOOGLE_MAX_DOWNLOAD_CONDITIONS,
 )
 from ..shared import emails
 from ..shared.gcloud_client import (
     publish_artifact_upload,
     grant_download_access,
-    grant_lister_access,
     refresh_intake_access,
     revoke_download_access,
-    revoke_lister_access,
 )
 from ..config.logging import get_logger
 
@@ -548,19 +545,6 @@ class Permissions(CommonColumns):
 
         is_network_viewer = grantee.role == CIDCRole.NETWORK_VIEWER.value
 
-        # A user can only have 20 granular permissions at a time, due to GCS constraints
-        # (with the exception of Network Viewers, who can't download data from GCS and aren't
-        # subject to this constraint.)
-        if not is_network_viewer and (
-            len(Permissions.find_for_user(self.granted_to_user, session=session))
-            >= GOOGLE_MAX_DOWNLOAD_CONDITIONS
-        ):
-            raise IntegrityError(
-                params=None,
-                statement=None,
-                orig=f"{grantee.email} has greater than or equal to the maximum number of allowed granular permissions ({GOOGLE_MAX_DOWNLOAD_CONDITIONS}). Remove unused permissions to add others.",
-            )
-
         logger.info(
             f"admin-action: {grantor.email} gave {grantee.email} the permission {self.upload_type or 'all assays'} on {self.trial_id or 'all trials'}"
         )
@@ -601,9 +585,7 @@ class Permissions(CommonColumns):
             return
 
         try:
-            # if they have any download permissions, they need the CIDC Lister role
-            grant_lister_access(grantee.email)
-            # Grant IAM permission in GCS only if db insert worked
+            # Grant ACL download permissions in GCS
             grant_download_access(grantee.email, self.trial_id, self.upload_type)
             # Remove permissions staged for deletion, if any
             for perm in perms_to_delete:
@@ -637,18 +619,12 @@ class Permissions(CommonColumns):
         if deleted_by_user is None:
             raise NoResultFound(f"no user with id {deleted_by}")
 
-        # Only make GCS IAM changes if this user has download access
+        # Only make GCS ACL changes if this user has download access
         if grantee.role != CIDCRole.NETWORK_VIEWER.value:
             try:
-                # Revoke IAM permission in GCS
+                # Revoke ACL permission in GCS
                 revoke_download_access(grantee.email, self.trial_id, self.upload_type)
 
-                # If the permission to delete is the last one, also revoke Lister access
-                filter_ = lambda q: q.filter(Permissions.granted_to_user == grantee.id)
-                if Permissions.count(session=session, filter_=filter_) <= 1:
-                    # this one hasn't been deleted yet, so 1 means this is the last one
-                    revoke_lister_access(grantee.email)
-
             except Exception as e:
                 raise IAMException(
                     "IAM revoke failed, and permission db record not removed."
@@ -712,9 +688,6 @@ class Permissions(CommonColumns):
             filter_=filter_for_user,
             session=session,
         )
-        # if they have any download permissions, they need the CIDC Lister role
-        if len(perms):
-            grant_lister_access(user.email)
         for perm in perms:
             # Regrant each permission to reset the TTL for this permission to
             # `settings.INACTIVE_USER_DAYS` from today.
@@ -728,17 +701,17 @@ class Permissions(CommonColumns):
 
     @staticmethod
     @with_default_session
-    def grant_all_iam_permissions(session: Session):
-        Permissions._change_all_iam_permissions(grant=True, session=session)
+    def grant_all_download_permissions(session: Session):
+        Permissions._change_all_download_permissions(grant=True, session=session)
 
     @staticmethod
     @with_default_session
-    def revoke_all_iam_permissions(session: Session):
-        Permissions._change_all_iam_permissions(grant=False, session=session)
+    def revoke_all_download_permissions(session: Session):
+        Permissions._change_all_download_permissions(grant=False, session=session)
 
     @staticmethod
     @with_default_session
-    def _change_all_iam_permissions(grant: bool, session: Session):
+    def _change_all_download_permissions(grant: bool, session: Session):
         perms = Permissions.list(page_size=Permissions.count(), session=session)
         for perm in perms:
             user = Users.find_by_id(perm.granted_to_user, session=session)
@@ -746,19 +719,10 @@ class Permissions(CommonColumns):
                 continue
 
             if grant:
-                grant_lister_access(user.email)
                 grant_download_access(user.email, perm.trial_id, perm.upload_type)
             else:
                 revoke_download_access(user.email, perm.trial_id, perm.upload_type)
 
-        # if un-granting things, revoke_lister_access as needed
-        if not grant:
-            for user in session.query(Users).all():
-                if user.is_admin() or user.is_nci_user() or user.disabled:
-                    continue
-                else:
-                    revoke_lister_access(user.email)
-
 
 class ValidationMultiError(Exception):
     """Holds multiple jsonschema.ValidationErrors"""
